diff --git a/litex/build/sim/core/modules/Makefile b/litex/build/sim/core/modules/Makefile
index 6782a192..314f1efc 100644
--- a/litex/build/sim/core/modules/Makefile
+++ b/litex/build/sim/core/modules/Makefile
@@ -1,5 +1,6 @@
 include ../variables.mak
-MODULES = xgmii_ethernet ethernet serial2console serial2tcp clocker spdeeprom
+MODULES = xgmii_ethernet ethernet serial2console serial2tcp clocker spdeeprom \
+	  jtagremote
 
 .PHONY: $(MODULES)
 all: $(MODULES)
diff --git a/litex/tools/litex_sim.py b/litex/tools/litex_sim.py
index fecbb65c..0ba4313f 100755
--- a/litex/tools/litex_sim.py
+++ b/litex/tools/litex_sim.py
@@ -172,6 +172,7 @@ class SimSoC(SoCCore):
         sdram_verbosity       = 0,
         with_i2c              = False,
         with_sdcard           = False,
+        with_jtag             = False,
         sim_debug             = False,
         trace_reset_on        = False,
         **kwargs):
@@ -184,9 +185,28 @@ class SimSoC(SoCCore):
             ident_version = True,
             **kwargs)
 
+
         # CRG --------------------------------------------------------------------------------------
         self.submodules.crg = CRG(platform.request("sys_clk"))
 
+        # JTAG -----------------------------------------------------------
+        if with_jtag:
+            # add JTAG platform pins
+            platform.add_extension([
+                ("jtag", 0,
+                    Subsignal("tck",  Pins(1)),
+                    Subsignal("tms", Pins(1)),
+                    Subsignal("tdi", Pins(1)),
+                    Subsignal("tdo", Pins(1)),
+                )
+            ])
+
+            jtagpads = platform.request("jtag")
+            self.comb += self.cpu.jtag_tck.eq(jtagpads.tck)
+            self.comb += self.cpu.jtag_tms.eq(jtagpads.tms)
+            self.comb += self.cpu.jtag_tdi.eq(jtagpads.tdi)
+            self.comb += jtagpads.tdo.eq(self.cpu.jtag_tdo)
+
         # SDRAM ------------------------------------------------------------------------------------
         if with_sdram:
             sdram_clk_freq = int(100e6) # FIXME: use 100MHz timings
@@ -384,6 +404,7 @@ def sim_args(parser):
     parser.add_argument("--remote-ip",            default="192.168.1.100", help="Remote IP address of TFTP server (default=192.168.1.100)")
     parser.add_argument("--with-analyzer",        action="store_true",     help="Enable Analyzer support")
     parser.add_argument("--with-i2c",             action="store_true",     help="Enable I2C support")
+    parser.add_argument("--with-jtagremote",      action="store_true",     help="Enable jtagremote support")
     parser.add_argument("--with-sdcard",          action="store_true",     help="Enable SDCard support")
     parser.add_argument("--trace",                action="store_true",     help="Enable Tracing")
     parser.add_argument("--trace-fst",            action="store_true",     help="Enable FST tracing (default=VCD)")
@@ -432,6 +453,9 @@ def main():
     if args.with_i2c:
         sim_config.add_module("spdeeprom", "i2c")
 
+    if args.with_jtagremote:
+        sim_config.add_module("jtagremote", "jtag", args={'port': 44853})
+
     trace_start = int(float(args.trace_start))
     trace_end = int(float(args.trace_end))
 
@@ -442,6 +466,7 @@ def main():
         with_etherbone = args.with_etherbone,
         with_analyzer  = args.with_analyzer,
         with_i2c       = args.with_i2c,
+        with_jtag      = args.with_jtagremote,
         with_sdcard    = args.with_sdcard,
         sim_debug      = args.sim_debug,
         trace_reset_on = trace_start > 0 or trace_end > 0,
